@@ -1,4 +1,4 @@
-/* main.c - Last modified: 13-Jun-2019 (kobayasy)
+/* main.c - Last modified: 03-Jul-2019 (kobayasy)
  *
  * Copyright (c) 2018-2019 by Yuichi Kobayashi <kobayasy@kobayasy.com>
  *
@@ -39,7 +39,7 @@
 #include "psync.h"
 #include "popen3.h"
 
-#define VERSION "1.15"
+#define VERSION "1.16"
 #define PROTID 0x01705370  /* 'p', 'S', 'p', 1 */
 #define CONFFILE ".psync.conf"
 #define EXPIRE_DEFAULT 400  /* [days] */
@@ -519,7 +519,6 @@ static int run_local_func(CLIST *clist, void *data) {
     SIGACT oldact;
     size_t length, n;
     int rack, lack;
-    char buffer[128];
     PSYNC *psync = NULL;
 
     sigactinit(&oldact);
@@ -531,10 +530,8 @@ static int run_local_func(CLIST *clist, void *data) {
     }
     READ_ONERR(rack, param->fdin, STATUS_HANDSHAKEERROR);
     if (!rack) {
-        if (g.verbose > 0) {
-            length = sprintf(buffer, "L%s\n", clist->name);
-            write(param->info, buffer, length);
-        }
+        if (g.verbose > 0)
+            dprintf(param->info, "L%s\n", clist->name);
         ONERR(sigactset(sighandler, &oldact), STATUS_SYSTEMERROR);
         psync = psync_new(clist->dirname, &g.stop);
         lack = psync == NULL ? -1 : 0;
@@ -555,10 +552,8 @@ static int run_local_func(CLIST *clist, void *data) {
         else
             status = STATUS_NOTREADYLOCAL;
         sigactreset(&oldact);
-        if (g.verbose > 0) {
-            length = sprintf(buffer, "L%+d %s\n", status, clist->name);
-            write(param->info, buffer, length);
-        }
+        if (g.verbose > 0)
+            dprintf(param->info, "L%+d %s\n", status, clist->name);
         if (ISERR(status))
             goto error;
     }
