@@ -1,4 +1,4 @@
-/* psync.c - Last modified: 13-Jun-2019 (kobayasy)
+/* psync.c - Last modified: 03-Jul-2019 (kobayasy)
  *
  * Copyright (c) 2018-2019 by Yuichi Kobayashi <kobayasy@kobayasy.com>
  *
@@ -445,27 +445,27 @@ static int progress_term(PROGRESS *progress) {
 
 static int lock(PRIV *priv) {
     int status = INT_MIN;
-    char loadname[PATH_MAX], *pload;
+    char loadname[PATH_MAX], *p;
 
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR, priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR, priv->dirname);
     mkdir(loadname, S_IRWXU);
-    strcpy(pload, "/"LOCKDIR);
+    strcpy(p, "/"LOCKDIR);
     status = mkdir(loadname, S_IRWXU) == -1 ? 1 : 0;
     return status;
 }
 
 static int unlock(PRIV *priv) {
     int status = INT_MIN;
-    char loadname[PATH_MAX], *pload;
-    char pathname[PATH_MAX], *p;
+    char loadname[PATH_MAX], *p;
+    char pathname[PATH_MAX], *name;
     struct timeval tv[2];
 
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR"/"LOCKDIR, priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR"/"LOCKDIR, priv->dirname);
     tv[0].tv_sec = priv->t, tv[0].tv_usec = 0;
     tv[1].tv_sec = priv->t, tv[1].tv_usec = 0;
     utimes(loadname, tv);
-    p = pathname, p += sprintf(p, "%s/"SYNCDIR"/", priv->dirname);
-    strftime(p, sizeof(pathname) - (p - pathname), BACKDIR, localtime(&priv->t));
+    name = pathname, name += sprintf(name, "%s/"SYNCDIR"/", priv->dirname);
+    strftime(name, sizeof(pathname) - (name - pathname), BACKDIR, localtime(&priv->t));
     status = rename(loadname, pathname) == -1 ? 1 : 0;
     return status;
 }
@@ -672,7 +672,7 @@ static int get_flocal(PRIV *priv) {
     int status = INT_MIN;
     struct stat st;
     DIR *dir = NULL;
-    char pathname[PATH_MAX], *p;
+    char pathname[PATH_MAX], *name;
     FLIST *flocal, *flast;
     struct dirent *ent;
 
@@ -696,7 +696,7 @@ static int get_flocal(PRIV *priv) {
         status = ERROR_FOPEN;
         goto error;
     }
-    p = pathname, p += sprintf(p, "%s/", priv->dirname);
+    name = pathname, name += sprintf(name, "%s/", priv->dirname);
     flocal = &priv->flocal, flast = &priv->fsynced;
     while ((ent = readdir(dir)) != NULL) {
         ONSTOP(priv->stop, ERROR_STOP);
@@ -704,8 +704,8 @@ static int get_flocal(PRIV *priv) {
             !strcmp(ent->d_name, "..") ||
             !strcmp(ent->d_name, SYNCDIR) )
             continue;
-        strcpy(p, ent->d_name);
-        status = get_flocal_r(&flocal, &flast, pathname, p, priv->stop);
+        strcpy(name, ent->d_name);
+        status = get_flocal_r(&flocal, &flast, pathname, name, priv->stop);
         if (ISERR(status))
             goto error;
     }
@@ -827,23 +827,23 @@ static int make_fsynced_get_func(FSETS sets, FLIST *flocal, FLIST *fremote, void
 static int preload(PRIV *priv) {
     int status = INT_MIN;
     intmax_t uploadsize, downloadsize;
-    char pathname[PATH_MAX], *p;
-    char loadname[PATH_MAX], *pload;
+    char pathname[PATH_MAX], *name;
+    char loadname[PATH_MAX], *p;
     unsigned long count;
     FLIST *fsynced;
     char buffer[SYMLINK_MAX];
 
     uploadsize = 0, downloadsize = 0;
-    p = pathname, p += sprintf(p, "%s/", priv->dirname);
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
+    name = pathname, name += sprintf(name, "%s/", priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
     count = 0;
     for (fsynced = priv->fsynced.next; *fsynced->name; fsynced = fsynced->next) {
         ONSTOP(priv->stop, ERROR_STOP);
         switch (fsynced->st.flags & (FST_UPLD|FST_LTYPE)) {
         case FST_UPLD|FST_LREG:
         case FST_UPLD|FST_LLNK:
-            strcpy(p, fsynced->name);
-            sprintf(pload, UPFILE, ++count);
+            strcpy(name, fsynced->name);
+            sprintf(p, UPFILE, ++count);
             switch (fsynced->st.flags & FST_LTYPE) {
             case FST_LREG:
                 if (link(pathname, loadname) == -1) {
@@ -882,7 +882,7 @@ static int upload(PRIV *priv) {
     int status = INT_MIN;
     intmax_t uploadsize;
     PROGRESS progress;
-    char loadname[PATH_MAX], *pload;
+    char loadname[PATH_MAX], *p;
     unsigned long count;
     FLIST *fsynced;
     off_t size;
@@ -891,14 +891,14 @@ static int upload(PRIV *priv) {
     char buffer[LOADBUFFER_SIZE];
 
     progress_init(&progress, priv->info, PROGRESS_INTERVAL, "U%+jd\n", uploadsize = 0);
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
     count = 0;
     for (fsynced = priv->fsynced.next; *fsynced->name; fsynced = fsynced->next) {
         ONSTOP(priv->stop, ERROR_STOP);
         switch (fsynced->st.flags & (FST_UPLD|FST_LTYPE)) {
         case FST_UPLD|FST_LREG:
         case FST_UPLD|FST_LLNK:
-            sprintf(pload, UPFILE, ++count);
+            sprintf(p, UPFILE, ++count);
             size = fsynced->st.size;
             switch (fsynced->st.flags & FST_LTYPE) {
             case FST_LREG:
@@ -954,7 +954,7 @@ static int download(PRIV *priv) {
     int status = INT_MIN;
     intmax_t downloadsize;
     PROGRESS progress;
-    char loadname[PATH_MAX], *pload;
+    char loadname[PATH_MAX], *p;
     unsigned long count;
     FLIST *fsynced;
     off_t size;
@@ -964,14 +964,14 @@ static int download(PRIV *priv) {
     struct timeval tv[2];
 
     progress_init(&progress, priv->info, PROGRESS_INTERVAL, "D%+jd\n", downloadsize = 0);
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
     count = 0;
     for (fsynced = priv->fsynced.next; *fsynced->name; fsynced = fsynced->next) {
         ONSTOP(priv->stop, ERROR_STOP);
         switch (fsynced->st.flags & (FST_DNLD|FST_RTYPE)) {
         case FST_DNLD|FST_RREG:
         case FST_DNLD|FST_RLNK:
-            sprintf(pload, DOWNFILE, ++count);
+            sprintf(p, DOWNFILE, ++count);
             size = fsynced->st.size;
             switch (fsynced->st.flags & FST_RTYPE) {
             case FST_RREG:
@@ -1036,27 +1036,27 @@ error:
 
 static int commit(PRIV *priv) {
     int status = INT_MIN;
-    char pathname[PATH_MAX], *p;
-    char loadname[PATH_MAX], *pload;
+    char pathname[PATH_MAX], *name;
+    char loadname[PATH_MAX], *p;
     unsigned long count;
     FLIST *fsynced;
     struct timeval tv[2];
 
-    p = pathname, p += sprintf(p, "%s/", priv->dirname);
-    pload = loadname, pload += sprintf(pload, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
+    name = pathname, name += sprintf(name, "%s/", priv->dirname);
+    p = loadname, p += sprintf(p, "%s/"SYNCDIR"/"LOCKDIR"/", priv->dirname);
     count = 0;
     for (fsynced = priv->fsynced.prev; *fsynced->name; fsynced = fsynced->prev)
         switch (fsynced->st.flags & (FST_DNLD|FST_LTYPE)) {
         case FST_DNLD|FST_LREG:
-            strcpy(p, fsynced->name);
-            sprintf(pload, BACKFILE, ++count, basename(p));
+            strcpy(name, fsynced->name);
+            sprintf(p, BACKFILE, ++count, basename(name));
             if (rename(pathname, loadname) == -1) {
                 status = ERROR_FMOVE;
                 goto error;
             }
             break;
         case FST_DNLD|FST_LLNK:
-            strcpy(p, fsynced->name);
+            strcpy(name, fsynced->name);
             if (unlink(pathname) == -1) {
                 status = ERROR_FREMOVE;
                 goto error;
@@ -1067,7 +1067,7 @@ static int commit(PRIV *priv) {
             case FST_RREG:
             case FST_RLNK:
             case 0:  /* deleted */
-                strcpy(p, fsynced->name);
+                strcpy(name, fsynced->name);
                 if (rmdir(pathname) == -1) {
                     status = ERROR_FREMOVE;
                     goto error;
@@ -1081,8 +1081,8 @@ static int commit(PRIV *priv) {
         switch (fsynced->st.flags & (FST_DNLD|FST_RTYPE)) {
         case FST_DNLD|FST_RREG:
         case FST_DNLD|FST_RLNK:
-            strcpy(p, fsynced->name);
-            sprintf(pload, DOWNFILE, ++count);
+            strcpy(name, fsynced->name);
+            sprintf(p, DOWNFILE, ++count);
             if (rename(loadname, pathname) == -1) {
                 status = ERROR_FMOVE;
                 goto error;
@@ -1093,14 +1093,14 @@ static int commit(PRIV *priv) {
             case FST_LREG:
             case FST_LLNK:
             case 0:  /* deleted */
-                strcpy(p, fsynced->name);
+                strcpy(name, fsynced->name);
                 if (mkdir(pathname, fsynced->st.mode & (S_IRWXU|S_IRWXG|S_IRWXO)) == -1) {
                     status = ERROR_FMAKE;
                     goto error;
                 }
                 break;
             case FST_LDIR:
-                strcpy(p, fsynced->name);
+                strcpy(name, fsynced->name);
                 if (chmod(pathname, fsynced->st.mode & (S_IRWXU|S_IRWXG|S_IRWXO)) == -1) {
                     status = ERROR_SWRITE;
                     goto error;
@@ -1112,7 +1112,7 @@ static int commit(PRIV *priv) {
     for (fsynced = priv->fsynced.prev; *fsynced->name; fsynced = fsynced->prev)
         switch (fsynced->st.flags & (FST_DNLD|FST_RTYPE)) {
         case FST_DNLD|FST_RDIR:
-            strcpy(p, fsynced->name);
+            strcpy(name, fsynced->name);
             tv[0].tv_sec = fsynced->st.mtime, tv[0].tv_usec = 0;
             tv[1].tv_sec = fsynced->st.mtime, tv[1].tv_usec = 0;
             if (lutimes(pathname, tv) == -1) {
@@ -1121,8 +1121,8 @@ static int commit(PRIV *priv) {
             }
             break;
         }
-    strcpy(p, SYNCDIR"/"LASTFILE);
-    strcpy(pload, LASTFILE);
+    strcpy(name, SYNCDIR"/"LASTFILE);
+    strcpy(p, LASTFILE);
     if (rename(loadname, pathname) == -1) {
         status = ERROR_DWRITE;
         goto error;
